@@ -182,68 +182,78 @@ ORDER BY desc(?data) LIMIT 1
             return None, None
 
     def _generate_migration_sparql_commands(self, origin_store,
-                                            destination_store, graph):
+                                            destination_store):
         diff = (origin_store - destination_store) or []
         checked = set()
         forward_migration = ""
         backward_migration = ""
 
-        for triples in diff:
-            triples_insert_l1 = ""
-            triples_insert_l2 = ""
-            query_1 = """\
-            prefix owl: <http://www.w3.org/2002/07/owl#>
-            prefix xsd: <http://www.w3.org/2001/XMLSchema#>
-            SELECT ?s WHERE
-            {
-                """
-            if isinstance(triples[0], rdflib.term.BNode) and (
-                                                    not triples[0] in checked):
-                checked.add(triples[0])
-                for sub_pred in diff.subject_predicates(triples[0]):
-                    query_1 = query_1 + "%s %s ?s . " % (sub_pred[0].n3(),
-                                                         sub_pred[1].n3())
-                    triples_insert_l1 = triples_insert_l1 + "%s %s " % (
-                                                              sub_pred[0].n3(),
-                                                              sub_pred[1].n3())
+        for subject, predicate, object_ in diff:
 
-                for pred_obj in diff.predicate_objects(triples[0]):
-                    query_1 = query_1 + "?s %s %s . " % (pred_obj[0].n3(),
-                                                         pred_obj[1].n3())
-                    triples_insert_l2 = triples_insert_l2 + "%s %s ; " % (
-                                                            pred_obj[0].n3(),
-                                                            pred_obj[1].n3())
-                query_1 = query_1 + "}"
+           if isinstance(subject, rdflib.term.BNode) and (
+                                                    not subject in checked):
+                checked.add(subject)
 
-                qres_1 = destination_store.query(query_1)
-                if len(qres_1) <= 0:
+                query_get_blank_node = """\
+                prefix owl: <http://www.w3.org/2002/07/owl#>
+                prefix xsd: <http://www.w3.org/2001/XMLSchema#>
+                SELECT DISTINCT ?s ?p ?o WHERE
+                {"""
+
+                blank_node_as_an_object = ""
+                triples_with_blank_node_as_object = sorted(diff.subject_predicates(subject))
+                for triple_subject, triple_predicate in triples_with_blank_node_as_object:
+                    query_get_blank_node = query_get_blank_node + "%s %s ?s . " % (triple_subject.n3(),
+                                                         triple_predicate.n3())
+                    blank_node_as_an_object = blank_node_as_an_object + "%s %s " % (
+                                                              triple_subject.n3(),
+                                                              triple_predicate.n3())
+
+                blank_node_as_a_subject = ""
+                triples_with_blank_node_as_subject = sorted(diff.predicate_objects(subject))
+                for triple_predicate, triple_object in triples_with_blank_node_as_subject:
+                    query_get_blank_node = query_get_blank_node + "?s %s %s . " % (
+                        triple_predicate.n3(), triple_object.n3())
+                    blank_node_as_a_subject = blank_node_as_a_subject + "%s %s ; " % (
+                        triple_predicate.n3(), Utils.get_normalized_n3(triple_object))
+
+                query_get_blank_node = query_get_blank_node + " ?s ?p ?o .} "
+
+                blank_node_existing_triples = len(destination_store.query(query_get_blank_node))
+                blank_node_existed_triples = len(origin_store.query(query_get_blank_node))
+
+                blank_node_triples_changed = blank_node_existing_triples != blank_node_existed_triples
+
+                if not blank_node_existing_triples or blank_node_triples_changed:
                     forward_migration = forward_migration + \
                         u"\nSPARQL INSERT INTO <%s> { %s[%s] };" % (
-                                                            graph,
-                                                            triples_insert_l1,
-                                                            triples_insert_l2)
-                    triples_insert_l2 = triples_insert_l2[:-2]
+                                                            self.__virtuoso_graph,
+                                                            blank_node_as_an_object,
+                                                            blank_node_as_a_subject)
+                    blank_node_as_a_subject = blank_node_as_a_subject[:-2]
+
                     backward_migration = backward_migration + \
                     (u"\nSPARQL DELETE FROM <%s> { %s ?s. ?s %s } WHERE "
-                    "{ %s ?s. ?s %s };") % (graph, triples_insert_l1,
-                                           triples_insert_l2,
-                                           triples_insert_l1,
-                                           triples_insert_l2)
+                    "{ %s ?s. ?s %s };") % (self.__virtuoso_graph, blank_node_as_an_object,
+                                           blank_node_as_a_subject,
+                                           blank_node_as_an_object,
+                                           blank_node_as_a_subject)
 
-            if isinstance(triples[0], rdflib.term.URIRef) and \
-                        not isinstance(triples[2], rdflib.term.BNode):
+           if isinstance(subject, rdflib.term.URIRef) and \
+                    not isinstance(object_, rdflib.term.BNode):
                 forward_migration = forward_migration + \
                                 u"\nSPARQL INSERT INTO <%s> {%s %s %s . };"\
-                                % (graph, triples[0].n3(), triples[1].n3(),
-                                   triples[2].n3())
+                                % (self.__virtuoso_graph, subject.n3(), predicate.n3(),
+                                   object_.n3())
                 backward_migration = backward_migration + \
-                    u"\nSPARQL DELETE FROM <%s> {%s %s %s . };" % (graph,
-                                                            triples[0].n3(),
-                                                            triples[1].n3(),
-                                                            triples[2].n3())
+                    u"\nSPARQL DELETE FROM <%s> {%s %s %s . };" % (self.__virtuoso_graph,
+                                                            subject.n3(),
+                                                            predicate.n3(),
+                                                            Utils.get_normalized_n3(object_))
 
         return forward_migration, backward_migration
 
+
     def get_sparql(self, current_ontology=None, destination_ontology=None,
                          current_version=None, destination_version=None,
                          origen=None, insert=None):
@@ -264,20 +274,16 @@ ORDER BY desc(?data) LIMIT 1
                 e._str = e._str.decode('utf-8')
                 raise MigrationException("Error parsing graph %s" % unicode(e))
 
-            forward_migration, backward_migration = (
+            forward_insert, backward_delete = (
                             self._generate_migration_sparql_commands(
                                                         destination_graph,
-                                                        current_graph,
-                                                        self.__virtuoso_graph))
-            query_up += forward_migration
-            query_down += backward_migration
-            forward_migration, backward_migration = (
+                                                        current_graph))
+            backward_insert, forward_delete = (
                             self._generate_migration_sparql_commands(
                                                         current_graph,
-                                                        destination_graph,
-                                                        self.__virtuoso_graph))
-            query_down += forward_migration
-            query_up += backward_migration
+                                                        destination_graph))
+            query_up = forward_delete + forward_insert
+            query_down = backward_delete + backward_insert
 
         # Registry schema changes on migration_graph
         now = datetime.datetime.now()
@@ -342,8 +348,7 @@ ORDER BY desc(?data) LIMIT 1
             raise Exception('migration file does not exist (%s)' % file_name)
         return Git(self._migrations_dir).execute(["git",
                                                   "show",
-                                                  version + ":" +\
-                                                    self.__virtuoso_ontology])
+                                                  version + ":" + self.__virtuoso_ontology])
 
     def get_ontology_from_file(self, filename):
         if not os.path.exists(filename):
